@@ -15,7 +15,7 @@ from tiddlyweb.model.user import User
 from tiddlyweb import __version__ as VERSION
 
 
-INTERNAL_PLUGINS = ['tiddlyweb.fromsvn', 'tiddlyweb.instancer']
+INTERNAL_PLUGINS = []
 
 COMMANDS = {}
 
@@ -36,12 +36,14 @@ def make_command():
         return func
     return decorate
 
+
 @make_command()
 def info(args):
     """Display info about TiddlyWeb."""
     print """This is TiddlyWeb version %s.
 The current store is: %s.""" % (VERSION, config['server_store'][0])
 
+
 @make_command()
 def server(args):
     """Start the server using config settings. Provide <host name or IP number> <port> to override."""
@@ -67,6 +69,52 @@ def server(args):
     serve.start_cherrypy()
 
 
+@make_command()
+def userpass(args):
+    """Change the password of an existing user. <username> <password>"""
+    try:
+        username, password = args[0:2]
+    except (IndexError, ValueError), exc:
+        print >> sys.stderr, "you must provide a user and a password: %s" % exc
+        usage()
+
+    try:
+        store = _store()
+        user = User(username)
+        user = store.get(user)
+        user.set_password(password)
+        store.put(user)
+    except Exception, exc:
+        print >> sys.stderr, 'unable to set password for user: %s' % exc
+        usage()
+
+    return True
+
+
+@make_command()
+def addrole(args):
+    """Add a role to an existing user. <username> [role] [role] [role]"""
+    try:
+        username = args.pop(0)
+        roles = args[0:]
+    except (IndexError, ValueError), exc:
+        print >> sys.stderr, "you must provide a user and at least one role: %s" % exc
+        usage()
+
+    try:
+        store = _store()
+        user = User(username)
+        user = store.get(user)
+        for role in roles:
+            user.add_role(role)
+        store.put(user)
+    except Exception, exc:
+        print >> sys.stderr, 'unable to add role to user: %s' % exc
+        usage()
+
+    return True
+
+
 @make_command()
 def adduser(args):
     """Add or update a user to the database: <username> <password> [[role] [role] ...]"""
@@ -95,24 +143,6 @@ def adduser(args):
     return True
 
 
-@make_command()
-def imwiki(args):
-    """Import a Tiddlywiki html file into a bag: <filename> <bag>"""
-    from tiddlyweb.importer import import_wiki_file
-
-    store = _store()
-
-    try:
-        filename, bag_name = args[0:2]
-        import_wiki_file(store, filename, bag_name)
-    except IndexError, exc:
-        print >> sys.stderr, "index error: %s" % exc
-        usage()
-    except ValueError, exc:
-        print >> sys.stderr, "value error: %s" % exc
-        usage()
-
-
 @make_command()
 def recipe(args):
     """Create or update a recipe with the recipe text on stdin: <recipe>"""
